@@ -51,7 +51,7 @@ end
 
 def installed_addon_files(addon)
   descriptor = File.join($sources_root, 'spec/data/registry/' + addon + '.yaml')
-  if !File.exists?(descriptor) || YAML.load_file(descriptor)['files']
+  if !File.exist?(descriptor) || YAML.load_file(descriptor)['files']
     Dir.glob(File.join($tmpdir, '*', addon + '.vim'))
   else
     Dir.glob(File.join($tmpdir, 'vam', addon))
@@ -92,5 +92,5 @@ Given /^(\S*) was previously installed as an old\-style addon$/ do |addon|
 end
 
 Given /^there should be no broken symlinks$/ do
-  expect(Dir.glob(File.join($tmpdir, '**/*')).select { |f| File.symlink?(f) && !File.exists?(f) }).to be_empty
+  expect(Dir.glob(File.join($tmpdir, '**/*')).select { |f| File.symlink?(f) && !File.exist?(f) }).to be_empty
 end
