@@ -19,7 +19,7 @@ module VimAddonManagerSpecHelper
     end
     alias :to_s :path
     def has_file?(file)
-      File.exists?(File.join(path, file))
+      File.exist?(File.join(path, file))
     end
     def has_symlink?(file)
       File.symlink?(File.join(path, file))
